from enguard.configs.base import TextGenerationGuardrailConfig
from enguard.guardrails.base import BaseGuardrail


class TextGenerationGuardrail(BaseGuardrail):
    def __init__(self, config: TextGenerationGuardrailConfig) -> None:
        super().__init__()



from typing import Dict, List

from transformers import pipeline

from enguard.configs.base import (
    TextClassificationGuardrailConfig,
)
from enguard.guardrails.base import BaseGuardrail


class TextClassificationGuardrail(BaseGuardrail):
    def __init__(
        self,
        config: TextClassificationGuardrailConfig,
        **kwargs,
    ):
        self.model = pipeline(
            task="text-classification",
            model=config.name,
            **kwargs,
        )

    def __call__(
        self,
        text_or_messages: str | List[Dict[str, str]] | List[str | List[Dict[str, str]]],
    ) -> str:
        return



from typing import Literal

from pydantic import BaseModel

AVAILABLE_ROLES = Literal["user", "assistant", "generic"]
AVAILABLE_GUARDRAIL_TYPES = Literal["prompt_injection", "jailbreak"]


class BaseGuardrailConfig(BaseModel):
    name: str
    description: str = ""
    role_index: AVAILABLE_ROLES


class TextClassificationGuardrailConfig(BaseGuardrailConfig):
    guardrail_type: Literal["text_classification"] = "text_classification"
    positive_labels: list[str]
    negative_labels: list[str]


class ImageClassificationGuardrailConfig(BaseGuardrailConfig):
    guardrail_type: Literal["text_classification"] = "text_classification"
    positive_labels: list[str]
    negative_labels: list[str]


class TokenClassificationGuardrailConfig(BaseGuardrailConfig):
    guardrail_type: Literal["token_classification"] = "token_classification"
    positive_labels: list[str]
    negative_labels: list[str]


class TextGenerationGuardrailConfig(BaseGuardrailConfig):
    guardrail_type: Literal["text_generation"] = "text_generation"


class ImageTextToTextGuardrailConfig(BaseGuardrailConfig):
    guardrail_type: Literal["image_text_to_text"] = "image_text_to_text"
    positive_labels: list[str]
    negative_labels: list[str]



from enguard.configs.base import ImageClassificationGuardrailConfig
from enguard.guardrails.base import BaseGuardrail


class ImageClassificationGuardrail(BaseGuardrail):
    def __init__(self, config: ImageClassificationGuardrailConfig) -> None:
        super().__init__()



from enguard.guardrails.image_classification import ImageClassificationGuardrail
from enguard.guardrails.image_text_to_text import ImageTextToTextGuardrail
from enguard.guardrails.text_classification import TextClassificationGuardrail
from enguard.guardrails.text_generation import TextGenerationGuardrail
from enguard.guardrails.token_classification import TokenClassificationGuardrail

__all__ = [
    "ImageClassificationGuardrail",
    "TokenClassificationGuardrail",
    "TextClassificationGuardrail",
    "TextGenerationGuardrail",
    "ImageTextToTextGuardrail",
]



from enguard.configs.base import ImageTextToTextGuardrailConfig
from enguard.guardrails.base import BaseGuardrail


class ImageTextToTextGuardrail(BaseGuardrail):
    def __init__(self, config: ImageTextToTextGuardrailConfig) -> None:
        super().__init__()



from enguard.configs.base import (
    AVAILABLE_GUARDRAIL_TYPES,
    TextClassificationGuardrail,
)

TEXT_CLASSIFICATION_GUARDRAILS = [
    TextClassificationGuardrail(
        name="meta-llama/Prompt-Guard-86M",
        guardrail_types=["prompt_injection", "jailbreak"],
    )
]


for guardrail in TEXT_CLASSIFICATION_GUARDRAILS:
    assert all(
        guardrail_type in AVAILABLE_GUARDRAIL_TYPES
        for guardrail_type in guardrail.guardrail_types
    )



from enguard.configs.base import (
    AVAILABLE_GUARDRAIL_TYPES,
    BaseGuardrailConfig,
    TextClassificationGuardrail,
)

GUARDRAILS = [
    TextClassificationGuardrail(
        name="meta-llama/Prompt-Guard-86M",
        guardrail_types=["prompt_injection", "jailbreak"],
    )
]


for guardrail in GUARDRAILS:
    assert all(
        guardrail_type in AVAILABLE_GUARDRAIL_TYPES
        for guardrail_type in guardrail.guardrail_types
    )


def get_guardrail_from_type(
    guardrail_type: AVAILABLE_GUARDRAIL_TYPES,
) -> BaseGuardrailConfig:
    for guardrail in GUARDRAILS:
        if guardrail_type in guardrail.guardrail_types:
            return guardrail
    raise ValueError(f"Guardrail type {guardrail_type} not found")



from enguard.configs.base import TextClassificationGuardrail
from enguard.configs.text_classification import TEXT_CLASSIFICATION_GUARDRAILS


def get_guardrails_from_architecture(
    architecture: str,
) -> TextClassificationGuardrail:
    potential_guardrails = []
    for guardrail in TEXT_CLASSIFICATION_GUARDRAILS:
        if guardrail.name == architecture:
            potential_guardrails.append(guardrail)
    if len(potential_guardrails) == 0:
        raise ValueError(f"Guardrail for architecture {architecture} not found")
    return potential_guardrails


def get_guardrail_from_type(
    guardrail_type: AVAILABLE_GUARDRAIL_TYPES,
) -> BaseGuardrail:
    for guardrail in TEXT_CLASSIFICATION_GUARDRAILS:
        if guardrail.guardrail_type == guardrail_type:
            return guardrail
    raise ValueError(f"Guardrail type {guardrail_type} not found")
